import numpy as np
from sklearn import preprocessing, cross_validation, svm
import pandas as pd
from sklearn.decomposition import PCA
from DEAP.GuoK_KandraH_Paper.DWT_analysis import svm_dwt_plot as data

""" 
Classifier: SVM (Kernel = sigmod)

Hold-Out: 80-20 (test_size = 0.2)

FEATURE EXTRACTION  DWT (Time Domain)
Valence mean accuracy:  56.53%      STD:  0.011804998794271267
Arousal mean accuracy:  58.83%      STD:  011282838371221501

"""
accuracy_valence = np.array([])
for i in range(1, 32):
    if i < 10:
        b = '0' + str(i)
    else:
        b = str(i)
    f = 'testfile_' + b + '.txt'
    df = pd.read_csv('data/'+f)
    df.drop(['user'], 1, inplace=True)
    df.drop(['video'], 1, inplace=True)
    df.drop(['wavesegment'], 1, inplace=True)
    df.drop(['combined'], 1, inplace=True)
    df.drop(['arousal'], 1, inplace=True)

    X = np.array(df.drop(['valence'], 1))
    y = np.array(df['valence'])
    X_train, X_test, y_train, y_test = cross_validation.train_test_split(X, y, test_size=0.2)
    pca = PCA(n_components=2)  # adjust yourself
    pca.fit(X_train)
    X_t_train = pca.transform(X_train)
    X_t_test = pca.transform(X_test)
    lin_clf = svm.SVC(C=1.0, cache_size=200, class_weight=None, coef0=0.0,
                      decision_function_shape='ovo', degree=3, gamma='auto', kernel='sigmoid',
                      max_iter=-1, probability=False, random_state=None, shrinking=True,
                      tol=0.001, verbose=False)
    lin_clf.fit(X_train, y_train)
    accuracy = lin_clf.score(X_test, y_test)
    accuracy_valence = np.append(accuracy_valence, accuracy)
    print("File: ", i, "\nAcurracy: ", accuracy)

mean_valence = np.mean(accuracy_valence)*100
print("\nValence Mean Acurracy: " + "%.2f" % mean_valence)
print("\nSTD:\n", np.std(accuracy_valence))

print("-----------------------------------------------------------")

accuracy_arousal = np.array([])
for i in range(1, 32):
    if i < 10:
        b = '0' + str(i)
    else:
        b = str(i)
    f = 'testfile_' + b + '.txt'
    df = pd.read_csv('data/'+f)
    df.drop(['user'], 1, inplace=True)
    df.drop(['video'], 1, inplace=True)
    df.drop(['wavesegment'], 1, inplace=True)
    df.drop(['combined'], 1, inplace=True)
    df.drop(['valence'], 1, inplace=True)
    X = np.array(df.drop(['arousal'], 1))
    y = np.array(df['arousal'])
    X_train, X_test, y_train, y_test = cross_validation.train_test_split(X, y, test_size=0.2)
    lin_clf = svm.SVC(C=1.0, cache_size=200, class_weight=None, coef0=0.0,
                          decision_function_shape='ovo', degree=3, gamma='auto', kernel='sigmoid',
                          max_iter=-1, probability=False, random_state=None, shrinking=True,
                          tol=0.001, verbose=False)
    lin_clf.fit(X_train, y_train)
    accuracy = lin_clf.score(X_test, y_test)
    accuracy_arousal = np.append(accuracy_arousal, accuracy)
    print("File: ", i, "\nAcurracy: ", accuracy)

mean_arousal = np.mean(accuracy_arousal)*100
print("\nArousal Mean Acurracy: " + "%.2f" % mean_arousal)
print("\nSTD:\n", np.std(accuracy_arousal))

data.plot(accuracy_valence, accuracy_arousal)
