# Affect recognition via EEG
import numpy as np

#Classical Classifiers
from sklearn import svm
from sklearn.ensemble import RandomForestClassifier
from sklearn.neural_network import MLPClassifier

#Feature selection PCA for Classical Classifiers
from sklearn.feature_selection import SelectKBest
from sklearn.feature_selection import f_classif

#Riemannian Classifier
from pyriemann.estimation import Covariances
from pyriemann.classification import MDM
from sklearn.model_selection import cross_val_score

class classifiers(object):
    def __init__(self, cv=5, k_pca=5, n_jobs=-1, scoring='f1', estimator='lwf'):
        self.cv = cv
        self.k_pca = k_pca
        self.n_jobs = n_jobs
        self.scoring = scoring
        self.estimator = estimator

    def svmClassifier(self, x, y, option):
        if option == 'v':
            pca_result = SelectKBest(f_classif, self.k_pca).fit_transform(x, y)
            pca_result = x
            svmRBFValence = svm.SVC()
            a = cross_val_score(svmRBFValence, pca_result, y, cv=self.cv, scoring=self.scoring, n_jobs=self.n_jobs)
            return np.mean(a) * 100, np.std(a)

        elif option == 'a':
            pca_result = SelectKBest(f_classif, self.k_pca).fit_transform(x, y)
            pca_result = x
            svmRBFArousal = svm.SVC()
            a = cross_val_score(svmRBFArousal, pca_result, y, cv=self.cv, scoring=self.scoring, n_jobs=self.n_jobs)
            return np.mean(a) * 100, np.std(a)

    def randomForestClassifier(self, x, y, option):
        if option == 'v':
            pca_result = SelectKBest(f_classif, self.k_pca).fit_transform(x, y)
            pca_result = x
            randomForestValence = RandomForestClassifier(n_estimators=10, max_depth=None, min_samples_split=2,
                                                         random_state=0)
            a = cross_val_score(randomForestValence, pca_result, y, cv=self.cv, scoring=self.scoring,
                                n_jobs=self.n_jobs)
            return np.mean(a) * 100, np.std(a)

        elif option == 'a':
            pca_result = SelectKBest(f_classif, self.k_pca).fit_transform(x, y)
            pca_result = x
            randomForestArousal = RandomForestClassifier(n_estimators=10, max_depth=None, min_samples_split=2,
                                                         random_state=0)
            a = cross_val_score(randomForestArousal, pca_result, y, cv=self.cv, scoring=self.scoring,
                                n_jobs=self.n_jobs)
            return np.mean(a) * 100, np.std(a)

    def mlpClassifier(self, x, y, option):
        if option == 'v':
            pca_result = SelectKBest(f_classif, self.k_pca).fit_transform(x, y)
            pca_result = x
            mlpValence = MLPClassifier()
            a = cross_val_score(mlpValence, pca_result, y, cv=self.cv, scoring=self.scoring, n_jobs=self.n_jobs)
            return np.mean(a) * 100, np.std(a)

        elif option == 'a':
            pca_result = SelectKBest(f_classif, self.k_pca).fit_transform(x, y)
            pca_result = x
            mlpArousal = MLPClassifier()
            a = cross_val_score(mlpArousal, pca_result, y, cv=self.cv, scoring=self.scoring, n_jobs=self.n_jobs)
            return np.mean(a) * 100, np.std(a)

    def riemannianMDM(self, x, y, option):
        if option == 'v':
            mdm = MDM()
            cov = Covariances(self.estimator).transform(x)
            a = cross_val_score(mdm, cov, y, cv=10, n_jobs=self.n_jobs)
            return np.mean(a) * 100, np.std(a)
        elif option == 'a':
            mdm = MDM()
            cov = Covariances(self.estimator).transform(x)
            a = cross_val_score(mdm, cov, y, cv=10, n_jobs=self.n_jobs)
            return np.mean(a) * 100, np.std(a)

