import pandas as pd
import numpy as np
import matplotlib.pyplot as plt


def plot_fgmdm(path):
    file = pd.read_csv(path)
    print("---------------------------------------------------------------------")
    print("\nFGMDM Perfomance Valence: ", file.valence_Score_Acc_3.mean(), "% - STD: ", file.valence_STD_3.mean())
    print("\nFGMDM Perfomance Arousal: ", file.arousal_Score_Acc_3.mean(), "% - STD: ", file.arousal_STD_3.mean())

    data = file.valence_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Valence')
    plt.title('Valence Histogram \n FGMDM Classifier')
    plt.savefig('figures_plot_results/HV-FGMDM-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    data = file.arousal_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Arousal')
    plt.title('Arousal Histogram \n FGMDM Classifier')
    plt.savefig('figures_plot_results/HA-FGMDM-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)
    plt.figure()
    plt.plot(file.subject, file.valence_Score_Acc_3, color='blue', linewidth=1.0, linestyle="-", marker='o',
             label='Valence')
    plt.plot(file.subject, file.arousal_Score_Acc_3, color='red', linewidth=1.0, linestyle="-.", marker='o',
             label='Arousal')
    plt.ylabel('Accuracy (in %)')
    plt.xlabel('Subjects')
    plt.legend()
    plt.grid(True)
    plt.xlim(0, 35)
    plt.title('Valence and Arousal Average Accuracy for 32 Test Subjects \n FGMDM Classifier')
    plt.savefig('figures_plot_results/GG-FGMDM-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)


def plot_mdm(path):
    file = pd.read_csv(path)
    print("---------------------------------------------------------------------")
    print("\nMDM Perfomance Valence: ", file.valence_Score_Acc_3.mean(), "% - STD: ", file.valence_STD_3.mean())
    print("\nMDM Perfomance Arousal: ", file.arousal_Score_Acc_3.mean(), "% - STD: ", file.arousal_STD_3.mean())

    data = file.valence_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Valence')
    plt.title('Valence Histogram \n MDM Classifier')
    plt.savefig('figures_plot_results/HV-MDM-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    data = file.arousal_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Arousal')
    plt.title('Arousal Histogram \n MDM Classifier')
    plt.savefig('figures_plot_results/HA-MDM-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    plt.figure()
    plt.plot(file.subject, file.valence_Score_Acc_3, color='blue', linewidth=1.0, linestyle="-", marker='o',
             label='Valence')
    plt.plot(file.subject, file.arousal_Score_Acc_3, color='red', linewidth=1.0, linestyle="-.", marker='o',
             label='Arousal')
    plt.ylabel('Accuracy (in %)')
    plt.xlabel('Subjects')
    plt.legend()
    plt.grid(True)
    plt.xlim(0, 35)
    plt.title('Valence and Arousal Average Accuracy for 32 Test Subjects \n MDM Classifier')
    plt.savefig('figures_plot_results/GG-MDM-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

def plot_lr(path):
    file = pd.read_csv(path)
    print("---------------------------------------------------------------------")
    print("\nLR Perfomance Valence: ", file.valence_Score_Acc_3.mean(), "% - STD: ", file.valence_STD_3.mean())
    print("\nLR Perfomance Arousal: ", file.arousal_Score_Acc_3.mean(), "% - STD: ", file.arousal_STD_3.mean())

    data = file.valence_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Valence')
    plt.title('Valence Histogram \n LR Classifier')
    plt.savefig('figures_plot_results/HV-LR-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    data = file.arousal_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Arousal')
    plt.title('Arousal Histogram \n LR Classifier')
    plt.savefig('figures_plot_results/HA-LR-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    plt.figure()
    plt.plot(file.subject, file.valence_Score_Acc_3, color='blue', linewidth=1.0, linestyle="-", marker='o',
             label='Valence')
    plt.plot(file.subject, file.arousal_Score_Acc_3, color='red', linewidth=1.0, linestyle="-.", marker='o',
             label='Arousal')
    plt.ylabel('Accuracy (in %)')
    plt.xlabel('Subjects')
    plt.legend()
    plt.grid(True)
    plt.xlim(0, 35)
    plt.title('Valence and Arousal Average Accuracy for 32 Test Subjects \n LR Classifier')
    plt.savefig('figures_plot_results/GG-LR-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

def plot_svm(path):
    file = pd.read_csv(path)
    print("---------------------------------------------------------------------")
    print("\nSVM Perfomance Valence: ", file.valence_Score_Acc_3.mean(), "% - STD: ", file.valence_STD_3.mean())
    print("\nSVM Perfomance Arousal: ", file.arousal_Score_Acc_3.mean(), "% - STD: ", file.arousal_STD_3.mean())

    data = file.valence_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Valence')
    plt.title('Valence Histogram \n SVM Classifier')
    plt.savefig('figures_plot_results/HV-SVM-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    data = file.arousal_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Arousal')
    plt.title('Arousal Histogram \n SVM Classifier')
    plt.savefig('figures_plot_results/HA-SVM-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    plt.figure()
    plt.plot(file.subject, file.valence_Score_Acc_3, color='blue', linewidth=1.0, linestyle="-", marker='o',
             label='Valence')
    plt.plot(file.subject, file.arousal_Score_Acc_3, color='red', linewidth=1.0, linestyle="-.", marker='o',
             label='Arousal')
    plt.ylabel('Accuracy (in %)')
    plt.xlabel('Subjects')
    plt.legend()
    plt.grid(True)
    plt.xlim(0, 35)
    plt.title('Valence and Arousal Average Accuracy for 32 Test Subjects \n SVM Classifier')
    plt.savefig('figures_plot_results/GG-SVM-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

def plot_slda(path):
    file = pd.read_csv(path)
    print("---------------------------------------------------------------------")
    print("\nsLDA Perfomance Valence: ", file.valence_Score_Acc_3.mean(), "% - STD: ", file.valence_STD_3.mean())
    print("\nsLDA Perfomance Arousal: ", file.arousal_Score_Acc_3.mean(), "% - STD: ", file.arousal_STD_3.mean())

    data = file.valence_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Valence')
    plt.title('Valence Histogram \n sLDA Classifier')
    plt.savefig('figures_plot_results/HV-sLDA-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    data = file.arousal_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Arousal')
    plt.title('Arousal Histogram \n sLDA Classifier')
    plt.savefig('figures_plot_results/HA-sLDA-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    plt.figure()
    plt.plot(file.subject, file.valence_Score_Acc_3, color='blue', linewidth=1.0, linestyle="-", marker='o',
             label='Valence')
    plt.plot(file.subject, file.arousal_Score_Acc_3, color='red', linewidth=1.0, linestyle="-.", marker='o',
             label='Arousal')
    plt.ylabel('Accuracy (in %)')
    plt.xlabel('Subjects')
    plt.legend()
    plt.grid(True)
    plt.xlim(0, 35)
    plt.title('Valence and Arousal Average Accuracy for 32 Test Subjects \n sLDA Classifier')
    plt.savefig('figures_plot_results/GG-sLDA-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

def plot_knn(path):
    file = pd.read_csv(path)
    print("---------------------------------------------------------------------")
    print("\nKNN Perfomance Valence: ", file.valence_Score_Acc_3.mean(), "% - STD: ", file.valence_STD_3.mean())
    print("\nKNN Perfomance Arousal: ", file.arousal_Score_Acc_3.mean(), "% - STD: ", file.arousal_STD_3.mean())

    data = file.valence_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Valence')
    plt.title('Valence Histogram \n KNN Classifier')
    plt.savefig('figures_plot_results/HV-KNN-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    data = file.arousal_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Arousal')
    plt.title('Arousal Histogram \n KNN Classifier')
    plt.savefig('figures_plot_results/HA-KNN-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    plt.figure()
    plt.plot(file.subject, file.valence_Score_Acc_3, color='blue', linewidth=1.0, linestyle="-", marker='o',
             label='Valence')
    plt.plot(file.subject, file.arousal_Score_Acc_3, color='red', linewidth=1.0, linestyle="-.", marker='o',
             label='Arousal')
    plt.ylabel('Accuracy (in %)')
    plt.xlabel('Subjects')
    plt.legend()
    plt.grid(True)
    plt.xlim(0, 35)
    plt.title('Valence and Arousal Average Accuracy for 32 Test Subjects \n KNN Classifier')
    plt.savefig('figures_plot_results/GG-KNN-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

def plot_bayes(path):
    file = pd.read_csv(path)
    print("---------------------------------------------------------------------")
    print("\nGB Perfomance Valence: ", file.valence_Score_Acc_3.mean(), "% - STD: ", file.valence_STD_3.mean())
    print("\nGB Perfomance Arousal: ", file.arousal_Score_Acc_3.mean(), "% - STD: ", file.arousal_STD_3.mean())

    data = file.valence_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Valence')
    plt.title('Valence Histogram \n GB Classifier')
    plt.savefig('figures_plot_results/HV-GB-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    data = file.arousal_Score_Acc_3
    plt.figure()
    data.plot(kind='hist', label='Arousal')
    plt.title('Arousal Histogram \n GB Classifier')
    plt.savefig('figures_plot_results/HA-GB-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

    plt.figure()
    plt.plot(file.subject, file.valence_Score_Acc_3, color='blue', linewidth=1.0, linestyle="-", marker='o',
             label='Valence')
    plt.plot(file.subject, file.arousal_Score_Acc_3, color='red', linewidth=1.0, linestyle="-.", marker='o',
             label='Arousal')
    plt.ylabel('Accuracy (in %)')
    plt.xlabel('Subjects')
    plt.legend()
    plt.grid(True)
    plt.xlim(0, 35)
    plt.title('Valence and Arousal Average Accuracy for 32 Test Subjects \n GB Classifier')
    plt.savefig('figures_plot_results/GG-GB-OFICIAL-15-36HZ.eps', format='eps', dpi=1000)

path1 = '/Users/ricklicona/PycharmProjects/deap_pBCI_Riemannian/DEAP/RIEMANNIAN_MDM/csv_results_classifiers/FGMDM-OFICIAL-15-36HZ'
plot_fgmdm(path1)

path2 = '/Users/ricklicona/PycharmProjects/deap_pBCI_Riemannian/DEAP/RIEMANNIAN_MDM/csv_results_classifiers/MDM-OFICIAL-15-36HZ'
plot_mdm(path2)

path3 = '/Users/ricklicona/PycharmProjects/deap_pBCI_Riemannian/DEAP/RIEMANNIAN_MDM/csv_results_classifiers/LR-TS-OFICIAL-15-36HZ'
plot_lr(path3)

path4 = '/Users/ricklicona/PycharmProjects/deap_pBCI_Riemannian/DEAP/RIEMANNIAN_MDM/csv_results_classifiers/SVM-TS-OFICIAL-15-36HZ'
plot_svm(path4)

path5 = '/Users/ricklicona/PycharmProjects/deap_pBCI_Riemannian/DEAP/RIEMANNIAN_MDM/csv_results_classifiers/SLDA-TS-OFICIAL-15-36HZ'
plot_slda(path5)

path6 = '/Users/ricklicona/PycharmProjects/deap_pBCI_Riemannian/DEAP/RIEMANNIAN_MDM/csv_results_classifiers/KNN-TS-OFICIAL-15-36HZ'
plot_knn(path6)

path7 = '/Users/ricklicona/PycharmProjects/deap_pBCI_Riemannian/DEAP/RIEMANNIAN_MDM/csv_results_classifiers/BAYES-TS-OFICIAL-15-36HZ'
plot_bayes(path7)
