import numpy as np
import gumpy

#RIEMANNIAN
from pyriemann.estimation import Covariances, Shrinkage
from pyriemann.classification import TSclassifier

#SCIKIT LEARN
from sklearn.cross_validation import KFold, cross_val_score
from sklearn.discriminant_analysis import LinearDiscriminantAnalysis


class Frequencies(object):

    def __init__(self, mean='logeuclid', distance='riemann'):
        self.mean = mean
        self.distance = distance
        self.clf = TSclassifier(metric='riemann', clf=LinearDiscriminantAnalysis(solver='lsqr', shrinkage='auto'))
        self.lo_alpha_beta_gamma, self.hi_alpha_beta_gamma = 15, 36
        # Define a monte-carlo cross-validation generator (reduce variance):
        self.cv = KFold(40, 10, shuffle=True, random_state=42)
        # self.cv = KFold(40, n_folds=40)
        # self.loo = KFold(40, n_folds=40)

    def getAlfa_Beta_Gamma(self, X, s, y_valence, y_arousal):
        print("\n----ALPHA-BETA-GAMMA-START---")
        # first step is to filter the data
        flt_a_b_g = gumpy.signal.butter_bandpass(X, lo=self.lo_alpha_beta_gamma, hi=self.hi_alpha_beta_gamma)

        # PREPARE FOR PIPELINE
        # compute covariance matrices
        cov_data_train = Covariances(estimator='lwf').transform(flt_a_b_g)
        cov_data_train = Shrinkage().transform(cov_data_train)

        # Use scikit-learn Pipeline with cross_val_score function
        scoresV = cross_val_score(self.clf, cov_data_train, y_valence, cv=self.cv)

        # Use scikit-learn Pipeline with cross_val_score function
        scoresA = cross_val_score(self.clf, cov_data_train, y_arousal, cv=self.cv)

        return np.mean(scoresV * 100), np.std(scoresV), np.mean(scoresA * 100), np.std(scoresA)
